VERONICA -- Tenants

# Tenant Management

New Tenant
Tenant ID *
Display Name *
Parent Tenant
Policy Overrides JSON (optional)
Tenants
Loading...
Select a tenant to view details.
Tenant Detail Editing
Tenant ID
Name
Name
Parent Tenant
Policy Overrides (0)
Policy Overrides JSON
Effective Policy

Resolved policy after applying parent overrides.

Loading...
Delete Tenant

Enter API Key

Provide your X-Veronica-Key to access tenant management.

API Key